@@ -16,6 +16,7 @@ import os
 import re
 import signal
 import subprocess
+import sys
 import threading
 
 import fixtures
@@ -57,33 +58,38 @@ class Driver(fixtures.Fixture):
         # NOTE(sileht): order matter, we first check into virtualenv
         # then global user installation, next system installation,
         # and to finish local user installation
-        check_dirs = ["/usr/local/etc",
+        check_dirs = [sys.prefix + "/etc",
+                      "/usr/local/etc",
                       "/etc",
                       os.path.expanduser("~/.local/etc")]
-        if "VIRTUAL_ENV" in os.environ:
-            check_dirs.insert(0, os.getenv("VIRTUAL_ENV") + "/etc")
         for d in check_dirs:
             fullpath = os.path.join(d, filename)
             if os.path.exists(fullpath):
                 return fullpath
         raise RuntimeError("Configuration file `%s' not found" % filename)
 
-    @staticmethod
-    def _read_in_bg(app, fd):
+    def _read_in_bg(self, app, pid, fd):
         while True:
             data = fd.readline()
             if not data:
                 break
-            LOG.debug("%s output: %s", app, data.rstrip())
+            self._log_output(app, pid, data)
+
+    @staticmethod
+    def _log_output(appname, pid, data):
+        LOG.debug("%s[%d] output: %s", appname, pid, data.rstrip())
 
     def _exec(self, command, stdout=False, ignore_failure=False,
-              stdin=None, wait_for_line=None, path=[], env=None):
+              stdin=None, wait_for_line=None, path=[], env=None,
+              allow_debug=True):
         LOG.debug("executing: %s" % command)
 
         complete_env = {}
         app = command[0]
 
-        if stdout or wait_for_line:
+        debug = allow_debug and LOG.isEnabledFor(logging.DEBUG)
+
+        if stdout or wait_for_line or debug:
             stdout_fd = subprocess.PIPE
         else:
             # TODO(jd) Need to close at some point
@@ -123,25 +129,27 @@ class Driver(fixtures.Fixture):
             lines = []
             while True:
                 line = c.stdout.readline()
-                LOG.debug("%s output: %s", app, line.rstrip())
+                self._log_output(app, c.pid, line)
+                lines.append(line)
                 if not line:
                     if wait_for_line:
                         raise RuntimeError(
-                            "Program did not print: `%s'"
-                            % wait_for_line)
+                            "Program did not print: `%s'\nOutput: %s"
+                            % (wait_for_line, b"".join(lines)))
                     break
-                lines.append(line)
                 if wait_for_line and re.search(wait_for_line, line.decode()):
                     break
-            # Continue to read
-            t = threading.Thread(target=self._read_in_bg,
-                                 args=(app, c.stdout,))
-            t.setDaemon(True)
-            t.start()
             stdout_str = b"".join(lines)
         else:
             stdout_str = None
 
+        if stdout or wait_for_line or debug:
+            # Continue to read
+            t = threading.Thread(target=self._read_in_bg,
+                                 args=(app, c.pid, c.stdout,))
+            t.setDaemon(True)
+            t.start()
+
         if not wait_for_line:
             status = c.wait()
             if not ignore_failure and status != 0:
